import java.io.*; 
import java.util.Scanner;
import java.util.ArrayList;

/******************************************************************************
*  List of available monster types (singleton pattern).
*
*  @author   Daniel R. Collins (dcollins@superdan.net)
*  @since    2014-07-18
*  @version  1.0
******************************************************************************/

public class MonsterList {
	//--------------------------------------------------------------------------
	//  Constants
	//--------------------------------------------------------------------------

	/** Name of file with monster information. */
	final String MONSTER_FILE = "Monsters.csv";

	//--------------------------------------------------------------------------
	//  Fields
	//--------------------------------------------------------------------------

	/** The singleton class instance. */
	static MonsterList instance = null;
	
	/** Array of Monster records. */
	ArrayList<Monster> monsterList;

	//--------------------------------------------------------------------------
	//  Constructors
	//--------------------------------------------------------------------------

	/**
	*  Constructor (read from dedicated file).
	*/
	protected MonsterList () throws IOException {
		String[][] table = CSVReader.readFile(MONSTER_FILE);
		monsterList = new ArrayList<Monster>();
		for (int i = 1; i < table.length; i++) {
			monsterList.add(new Monster(table[i]));
		}
	}

	//--------------------------------------------------------------------------
	//  Methods
	//--------------------------------------------------------------------------
	public int size() { return monsterList.size(); }
	public Monster get (int index) { return monsterList.get(index); }

	/**
	*  Access the singleton class instance.
	*/
	public static MonsterList getInstance() {
		if (instance == null) {
			try {
				instance = new MonsterList();
			}
			catch (IOException e) {
				System.out.println("Failed to read the Monsters file.");
			}
		}
		return instance;
	}

	/**
	*  Get a monster by matching its type.
	*/
	public Monster getByType (String type) {
		for (Monster m: monsterList) {
			if (m.getType().equalsIgnoreCase(type)) {
				return m;
			}
		}
		return null;
	}

	/**
	*  Main test method.
	*/
	public static void main (String[] args) {
		MonsterList ml = MonsterList.getInstance();
		for (int i = 0; i < ml.size(); i++) {
			System.out.println(ml.get(i));
		}
		System.out.println();
	}
}

